<?php

declare(strict_types=1);

namespace App\Controller\PunchCard\User;

use App\Controller\BaseController;
use App\JsonRpc\PunchCardSystemExternalServiceInterface;
use App\JsonRpc\UserExternalServiceInterface;
use App\Middleware\AuthMiddleware;
use Hyperf\Di\Annotation\Inject;
use Hyperf\HttpServer\Annotation\Controller;
use Hyperf\HttpServer\Annotation\GetMapping;
use Hyperf\HttpServer\Annotation\Middleware;
use Hyperf\HttpServer\Annotation\PostMapping;

#[Middleware(AuthMiddleware::class)]
#[Controller(prefix: "kq")]
class UserController extends BaseController
{
    /**
     * 用户中心对外RPC服务
     *
     * @var UserExternalServiceInterface
     */
    #[Inject]
    protected UserExternalServiceInterface $userExternalService;

    /**
     * 考勤系统设置对外RPC服务
     *
     * @var PunchCardSystemExternalServiceInterface
     */
    #[Inject]
    protected PunchCardSystemExternalServiceInterface $punchCardSystemExternalService;

    /**
     * 获取个人资料
     *
     * @return array
     */
    #[GetMapping(path: "user/information")]
    public function information() : array
    {
        $user = $this->request->getAttribute('AuthUser');
        return $this->getServiceResult($this->userExternalService->getUserInfo($user['openid'], [
            'user_name',
            'user_phone',
        ]));
    }

    /**
     * 保存个人资料
     *
     * @return void
     */
    #[PostMapping(path: "user/save_information")]
    public function saveInformation() : void
    {
        $phone = $this->request->input('phone', '');
        // TODO 逻辑完善
    }

    /**
     * 获取问题反馈类型列表
     *
     * @return array
     */
    #[GetMapping(path: "user/feedback_type")]
    public function getFeedbackTypeList() : array
    {
        return $this->getServiceResult($this->punchCardSystemExternalService->getFeedbackTypeList());
    }

    /**
     * 保存问题反馈
     *
     * @return array
     */
    #[PostMapping(path: "user/save_feedback")]
    public function saveFeedback() : array
    {
        $user = $this->request->getAttribute('AuthUser');
        return $this->getServiceResult($this->punchCardSystemExternalService->saveFeedback($this->request, $user['user_id']));
    }

    /**
     * 获取紧急联系人关系列表
     *
     * @return array
     */
    #[GetMapping(path: "user/emergency_contact_kinship")]
    public function getEmergencyContactKinshipList() : array
    {
        return $this->getServiceResult($this->userExternalService->getEmergencyContactKinshipList());
    }

    /**
     * 保存紧急联系人
     *
     * @return array
     */
    #[PostMapping(path: "user/add_emergency_contact")]
    public function addEmergencyContact() : array
    {
        return $this->getServiceResult($this->userExternalService->addEmergencyContact($this->request));
    }

    /**
     * 测试打印JWT认证信息
     *
     * @return array
     */
    #[GetMapping(path: "user/test")]
    public function test() : array
    {
        return $this->request->getAttribute('AuthUser');
    }
}
